@@ -1,11 +1,11 @@
 #
-# $Id: acct.sh,v 1.1 1996/01/06 02:04:15 lf Exp $
+# $Id: acct.sh,v 1.2 1996/01/07 03:14:30 lf Exp $
 #
 
 acct_start ()
 {
-	SID=`mksid`; export SID
-	START_TIME=`mktime`; export START_TIME
+	export SID=`mksid`
+	export START_TIME=`mktime`
 	
 	(
 		echo "Acct-Session-Id = \"$SID\""
@@ -17,6 +17,12 @@ acct_start ()
 		if [ $TYPE = "framed" ]
 		then
 			echo "Framed-Protocol = $RADIUS_FRAMED_PROTOCOL"
+			FTYPE="`echo $RADIUS_FRAMED_PROTOCOL | tr [A-Z] [a-z]`"
+			if [ $FTYPE = "ppp" ]
+			then
+				export START_IOCTETS=`ppptraffic -r $INAME`
+				export START_OOCTETS=`ppptraffic -s $INAME`
+			fi
 		fi
 	) | radacct
 }
@@ -30,12 +36,20 @@ acct_stop ()
 		echo "User-Name = \"$RADIUS_USER_NAME\""
 		echo "Acct-Status-Type = Stop"
 		echo "Acct-Authentic = RADIUS"
-		echo "Acct-Session-Time = `expr $STOP_TIME - $START_TIME`"
 		echo "Service-Type = $RADIUS_SERVICE_TYPE"
 		TYPE="`echo $RADIUS_SERVICE_TYPE | tr [A-Z] [a-z]`"
 		if [ $TYPE = "framed" ]
 		then
 			echo "Framed-Protocol = $RADIUS_FRAMED_PROTOCOL"
+			FTYPE="`echo $RADIUS_FRAMED_PROTOCOL | tr [A-Z] [a-z]`"
+			if [ $FTYPE = "ppp" ]
+			then
+				STOP_IOCTETS=`ppptraffic -r $INAME`
+				STOP_OOCTETS=`ppptraffic -s $INAME`
+				echo "Acct-Input-Octets = `expr $STOP_IOCTETS - $START_IOCTETS`"
+				echo "Acct-Output-Octets = `expr $STOP_OOCTETS - $START_OOCTETS`"
+			fi
 		fi
+		echo "Acct-Session-Time = `expr $STOP_TIME - $START_TIME`"
 	) | radacct
 }
